<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>AboutDialogPrivate</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="83"/>
        <source>Version: %1</source>
        <translation>Bertsioa: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="96"/>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Qt teknologietan oinarritutako mahaigain-ingurune aurreratu, erabilerraz eta azkarra.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="98"/>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>LXQt ez litzateke posible izango &lt;a %1&gt; Razor-qt &lt;/a&gt; proiektua eta bere laguntzaile asko gabe.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="100"/>
        <source>Copyright: © %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Copyright: © %1-%2 %3</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="102"/>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Webgunea: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="104"/>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Lizentzia: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="114"/>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="116"/>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="unfinished">Gure garapen taldearekin lan egitea interesatzen bazaizu, &lt;a %1&gt; batu gurekin &lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="133"/>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation>Eskerrik asko:</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="140"/>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation>LXQt hainbat hizkuntzetara itzulita dago mundu osoko itzulpen-taldeen lanari esker.</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="14"/>
        <source>About LXQt</source>
        <translation type="unfinished">LXQt-i buruz</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="66"/>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation>Honi buruz</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="83"/>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation>Egileak</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="100"/>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation>Eskerrak</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="117"/>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation>Itzulpenak</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="134"/>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation>Informazio teknikoa</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="165"/>
        <source>Copy to clipboard</source>
        <translation>Kopiatu arbelean</translation>
    </message>
</context>
</TS>
